from django.forms import MultipleHiddenInput as Mhi


class MultipleHiddenInput(Mhi):
    template_name = "web/forms/widgets/multiple_hidden.html"

    def __init__(self, attrs=None):
        super().__init__(attrs)
        self.attrs.update({'class': 'input'})



from django.utils.decorators import classonlymethod
from django.views.generic import TemplateView as Tv


class TemplateView(Tv):
    section_name = ""

    @classonlymethod
    def as_view(cls, section_name: str = "", **initkwargs):
        cls.section_name = section_name
        return super().as_view(**initkwargs)



from django.forms import CheckboxInput as Ci


class CheckboxInput(Ci):
    template_name = "web/forms/widgets/checkbox.html"

    def __init__(self, attrs=None, check_test=None):
        super().__init__(attrs, check_test)
        self.attrs.update({'class': 'checkbox'})



from django.utils.translation import ugettext as _
from django.urls import path
from msweb import views

urlpatterns = [
    # Home Page
    path(
        "",
        views.TemplateView.as_view(
            template_name="web/home.html",
            section_name=_('Home')
        ),
        name="muses_home"
    ),
    # About
    path(
        "about/",
        views.TemplateView.as_view(
            template_name="web/about.html",
            section_name=_('About')
        ),
        name="muses_about"
    ),
    # Faq
    path(
        "faq/",
        views.TemplateView.as_view(
            template_name="web/faq.html",
            section_name=_('Faq')
        ),
        name="muses_faq"
    ),
    # Terms of Use
    path(
        "terms_of_use/",
        views.TemplateView.as_view(
            template_name="web/terms_of_use.html",
            section_name=_('Terms of Use')
        )
    )
]



from django.forms import DateTimeInput as Dti


class DateTimeInput(Dti):
    def __init__(self, attrs=None, fmt=None):
        super().__init__(attrs, fmt)
        self.attrs.update({'class': 'input'})
